==> vtigercrm-5.3.0p0.tgz: modules/Products/language/es_mx.lang.php <==
<?php
/***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Products
*  Language     : Español
*  Version      : 504
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2008-09-20
*  Author       : Joe Bordes JPL TSolucio, S.L.
 *  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Productos',
'SINGLE_Products'=>'Producto',
'LBL_LIST_PRODUCT_NAME'=>'Producto',
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Producto',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Producto',
'LBL_PRODUCT_NAME'=>'Producto:',
'LBL_VENDOR_NAME'=>'Proveedor:',
'LBL_PRICEBOOK_NAME'=>'Listas de precios:',
'LBL_VENDOR'=>'Proveedor',
'LBL_PRICEBOOK'=>'Listas de precios:',
'LBL_VENDOR_INFORMATION'=>'Información del Proveedor:',
'LBL_PRICEBOOK_INFORMATION'=>'Información de las Listas de precios:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Información de la Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_PRICING_INFORMATION'=>'Información de Precios:',
'LBL_STOCK_INFORMATION'=>'Información del Stock:',
'LBL_LIST_FORM_TITLE'=>'Lista de productos',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Lista de Proveedores',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista de Listas de precios',
'LBL_LIST_CATEGORY'=>'Categoría de Producto',
'LBL_CATEGORY'=>'Categoría de Producto:',
'LBL_PRODUCT_CODE'=>'Código de Producto',
'LBL_LIST_PRODUCT_CODE'=>'Código de Producto:',
'LBL_PRODUCT_ACTIVE'=>'Producto Activo',
'LBL_PRODUCT_COMMISSION_RATE'=>'Comisión del Producto',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Cantidad/Unidad',
'LBL_PRODUCT_UNIT_PRICE'=>'Precio Unitario',
'LBL_PB_LIST_PRICE'=>'Lista de Precios',
'LBL_PRODUCT_DESCRIPTION'=>'Descripción',
'LBL_PRODUCT_IMAGE'=>'Imagen',
'LBL_NEW_FORM_TITLE'=>'Nuevo Producto',
'LBL_PRODUCT_INFORMATION'=>'Información del Producto',
'LBL_CUSTOM_INFORMATION'=>'Información personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción',

//New entry
'LBL_UPLOAD'=>'Adjuntar archivo',

'LBL_PRODUCT'=>'Producto',
'LBL_NEW_PRODUCT'=>'Nuevo Producto',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Adjuntos',
'LBL_ATTACH_FILE'=>'Archivo Adjunto',
'LBL_DESCRIPTION'=>'Descripción',
'LBL_FILE'=>'Nombre del Archivo',


//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TICKET'=>'Nuevo Caso',
'LBL_TICKET_TITLE'=>'Casos',

'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',

'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',

'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Fabricante',
'LBL_PRODUCTCATEGORY'=>'Categoría',
'LBL_SUPPORT_START_DATE'=>'Fecha de inicio del Soporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Fecha de fin del Soporte',
'LBL_PURCHASE_DATE'=>'Fecha de compra',

//Added for 4GA
'Product Name'=>'Nombre del Producto',
//'Product Code'=>'Part Number',
'Part Number'=>'Código de Producto',
'Product Active'=>'Producto Activo',
'Commission Rate'=>'Comisión (%)',
'Qty/Unit'=>'Cantidad/Unidad',
'Unit Price'=>'Precio Unitario',
'Manufacturer'=>'Fabricante',
'Product Category'=>'Categoría de Producto',
'Support Start Date'=>'Fecha de inicio de Soporte',
'Support Expiry Date'=>'Fecha de fin del Soporte',
'Purchase Date'=>'Fecha de Compra',
'Sales Start Date'=>'Fecha de salida al mercado',
'Sales End Date'=>'Fecha de retirada del mercado',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Related To'=>'Relacionado con',
'Usage Unit'=>'Unidad de Uso',
'Handler'=>'Responsable',
'Contact Name'=>'Nombre del Contacto',
'Currency'=>'Moneda',
'Reorder Level'=>'Nivel de pedido',
'Tax Class'=>'Clase de Impuesto',
'Mfr PartNo'=>'Nº de Pieza del Fabricante',
'Vendor PartNo'=>'Nº de Pieza del Proveedor',
'Serial No'=>'Nº de serie',
'Qty In Stock'=>'Cantidad en Stock',
'Product Sheet'=>'Hoja del Producto',
'Qty In Demand'=>'Cantidad Pedida',
'GL Account'=>'Cuenta contable',
'Vendor Name'=>'Nombre del Proveedor',

//Mapping for Name
'Name'=>'Nombre',
'Company Name'=>'Nombre de la Empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'Cuenta Contable',
'Category'=>'Categoría',
'Street'=>'Calle',
'City'=>'Deleg./Mpio.',
'State'=>'Estado',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Colonia',

//Mapping for price book
'Price Book Name'=>'Nombre de la Lista de precios ',
'Product Name'=>'Nombre de Producto',
'Active'=>'Activo',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todo',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Buscar Proveedor',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Buscar Listas de precios',
'LBL_VENDOR_TITLE'=>'Proveedores',
'LBL_PRICEBOOK_TITLE'=>'Listas de precios',
'LBL_PRODUCTS_TITLE'=>'Productos',
'LBL_COMPANY_NAME'=>'Nombre de la Empresa',
'LBL_CATEGORY_TITLE'=>'Categoría',
'LBL_ACTIVE_TITLE'=>'Activo',
'LBL_LIST_VENDOR_NAME'=>'Nombre del Proveedor',
'LBL_IMAGE_INFORMATION'=>'Información de la Imagen del Producto:',
'Product Image'=>'Imagen del Producto',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Agregar a las Listas de precios [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Agregar a las Listas de precios',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Agregar producto a las Listas de precios',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Agregar producto a las Listas de precios',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'El archivo excede el límite de tamaño máximo. Pruebe con otro archivo menor que 800Kbytes',
'LBL_UPLOAD_ERROR'=>'Problemas con el archivo. ¡Inténtelo de nuevo!',
'LBL_IMAGE_ERROR'=>'El archivo no es de tipo imágen(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Archivo inválido o sin datos',
'LBL_EMAIL'=>'Email',
'Product'=>'Producto',
'LBL_EDITLISTPRICE'=>'Editar Listas de precios',

//Added for existing picklist entries

'--None--'=>'-----',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'Aplicaciones CRM',

'300-Sales-Software'=>'300-Ventas-Software',
'301-Sales-Hardware'=>'301-Ventas-Hardware',
'302-Rental-Income'=>'302-Ingresos-Facturas',
'303-Interest-Income'=>'303-Ingresos-Intereses',
'304-Sales-Software-Support'=>'304-Ventas-Software-Soporte',
'305-Sales Other'=>'305-Ventas-Otros',
'306-Internet Sales'=>'306-Ventas Internet',
'307-Service-Hardware Labor'=>'307-Ventas-Instalación de Hardware',
'308-Sales-Books'=>'308-Libros-Ventas',

'Box'=>'Caja',
'Carton'=>'Cartón',
'Caton'=>'Caton',
'Dozen'=>'Docena',
'Each'=>'Unidad',
'Hours'=>'Horas',
'Impressions'=>'Impresiones',
'Lb'=>'Kg',
'M'=>'M',
'Pack'=>'Pack',
'Pages'=>'Páginas',
'Pieces'=>'Piezas',
'Quantity'=>'Cantidad',
'Reams'=>'Resma',
'Sheet'=>'Hoja',
'Spiral Binder'=>'Encuadernado Espiral',
'Sq Ft'=>'m&sup2;',

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'Stock Bajo',
'MSG_DEAR'=>'Querido',
'MSG_CURRENT_STOCK'=>'El Stock actual',
'MSG_IN_OUR_WAREHOUSE'=>'en nuestro almacén',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Atención al número de unidades, el stock está por debajo del nivel de reposición.',
'MSG_SEVERITY'=>'Importancia: Alta',
'MSG_THANKS'=>'Gracias, ',

// Added after 5.0.4 GA

'LBL_PRODUCT_PRICES'=>'Precios Productos',
'Member Of'=>'Miembro de',

// Module Sequence Numbering
'Product No' => 'Núm. Producto',
// END

'Parent Product' => 'Product Paterno',

'LBL_NO_TAXES_ASSOCIATED'=>'No hay impuestos asociados a este producto',
);

?>

==> vtigercrm-5.4.0.tgz: modules/Products/language/es_mx.lang.php <==
<?php
/***********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 ********************************************************************************
*  Module       : Products
*  Language     : Español
*  Version      : 5.4.0
*  Created Date : 2007-03-30
*  Author       : Rafael Soler
*  Last change  : 2012-02-28
*  Author       : Joe Bordes JPL TSolucio, S.L.
 *  Author       : Francisco Hernandez Odin Consultores www.odin.mx
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Productos',
'SINGLE_Products'=>'Producto',
'LBL_LIST_PRODUCT_NAME'=>'Producto',
'LBL_TOOL_FORM_TITLE'=>'Herramientas de Producto',
'LBL_SEARCH_FORM_TITLE'=>'Buscar Producto',
'LBL_PRODUCT_NAME'=>'Producto:',
'LBL_VENDOR_NAME'=>'Proveedor:',
'LBL_PRICEBOOK_NAME'=>'Listas de precios:',
'LBL_VENDOR'=>'Proveedor',
'LBL_PRICEBOOK'=>'Listas de precios:',
'LBL_VENDOR_INFORMATION'=>'Información del Proveedor:',
'LBL_PRICEBOOK_INFORMATION'=>'Información de las Listas de precios:',
'LBL_VENDOR_ADDRESS_INFORMATION'=>'Información de la Dirección:',
'LBL_DESCRIPTION_INFORMATION'=>'Información Adicional',
'LBL_PRICING_INFORMATION'=>'Información de Precios:',
'LBL_STOCK_INFORMATION'=>'Información del Stock:',
'LBL_LIST_FORM_TITLE'=>'Lista de productos',
'LBL_LIST_VENDOR_FORM_TITLE'=>'Lista de Proveedores',
'LBL_LIST_PRICEBOOK_FORM_TITLE'=>'Lista de Listas de precios',
'LBL_LIST_CATEGORY'=>'Categoría de Producto',
'LBL_CATEGORY'=>'Categoría de Producto:',
'LBL_PRODUCT_CODE'=>'Código de Producto',
'LBL_LIST_PRODUCT_CODE'=>'Código de Producto:',
'LBL_PRODUCT_ACTIVE'=>'Producto Activo',
'LBL_PRODUCT_COMMISSION_RATE'=>'Comisión del Producto',
'LBL_PRODUCT_QTY_PER_UNIT'=>'Cantidad/Unidad',
'LBL_PRODUCT_UNIT_PRICE'=>'Precio Unitario',
'LBL_PB_LIST_PRICE'=>'Lista de Precios',
'LBL_PRODUCT_DESCRIPTION'=>'Descripción',
'LBL_PRODUCT_IMAGE'=>'Imagen',
'LBL_NEW_FORM_TITLE'=>'Nuevo Producto',
'LBL_PRODUCT_INFORMATION'=>'Información del Producto',
'LBL_CUSTOM_INFORMATION'=>'Información personalizada',
'LBL_DESCRIPTION_INFORMATION'=>'Descripción',

//New entry
'LBL_UPLOAD'=>'Adjuntar archivo',

'LBL_PRODUCT'=>'Producto',
'LBL_NEW_PRODUCT'=>'Nuevo Producto',
'LBL_COLON'=>':',

'LBL_ATTACHMENTS'=>'Adjuntos',
'LBL_ATTACH_FILE'=>'Archivo Adjunto',
'LBL_DESCRIPTION'=>'Descripción',
'LBL_FILE'=>'Nombre del Archivo',


//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nueva Oportunidad',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TICKET'=>'Nuevo Caso',
'LBL_TICKET_TITLE'=>'Casos',

'LBL_NEW_CALL'=>'Nueva Llamada',
'LBL_CALL_TITLE'=>'Llamadas',

'LBL_NEW_MEETING'=>'Nueva Reunión',
'LBL_MEETING_TITLE'=>'Reuniones',

'LBL_NEW_ATTACHMENT'=>'Nuevo Adjunto',
'LBL_ATTACHMENT_TITLE'=>'Adjuntos',

//Added vtiger_fields after RC1 - Release
'LBL_MANUFACTURER'=>'Fabricante',
'LBL_PRODUCTCATEGORY'=>'Categoría',
'LBL_SUPPORT_START_DATE'=>'Fecha de inicio del Soporte',
'LBL_SUPPORT_EXPIRY_DATE'=>'Fecha de fin del Soporte',
'LBL_PURCHASE_DATE'=>'Fecha de compra',

//Added for 4GA
'Product Name'=>'Nombre del Producto',
//'Product Code'=>'Part Number',
'Part Number'=>'Código de Producto',
'Product Active'=>'Producto Activo',
'Commission Rate'=>'Comisión (%)',
'Qty/Unit'=>'Cantidad/Unidad',
'Unit Price'=>'Precio Unitario',
'Manufacturer'=>'Fabricante',
'Product Category'=>'Categoría de Producto',
'Support Start Date'=>'Fecha de inicio de Soporte',
'Support Expiry Date'=>'Fecha de fin del Soporte',
'Purchase Date'=>'Fecha de Compra',
'Sales Start Date'=>'Fecha de salida al mercado',
'Sales End Date'=>'Fecha de retirada del mercado',
'Created Time'=>'Fecha de Creación',
'Modified Time'=>'Última Modificación',
'Related To'=>'Relacionado con',
'Usage Unit'=>'Unidad de Uso',
'Handler'=>'Responsable',
'Contact Name'=>'Nombre del Contacto',
'Currency'=>'Moneda',
'Reorder Level'=>'Nivel de pedido',
'Tax Class'=>'Clase de Impuesto',
'Mfr PartNo'=>'Nº de Pieza del Fabricante',
'Vendor PartNo'=>'Nº de Pieza del Proveedor',
'Serial No'=>'Nº de serie',
'Qty In Stock'=>'Cantidad en Stock',
'Product Sheet'=>'Hoja del Producto',
'Qty In Demand'=>'Cantidad Pedida',
'GL Account'=>'Cuenta contable',
'Vendor Name'=>'Nombre del Proveedor',

//Mapping for Name
'Name'=>'Nombre',
'Company Name'=>'Nombre de la Empresa',
'Phone'=>'Teléfono',
'Email'=>'Email',
'Website'=>'Website',
'GL Account'=>'Cuenta Contable',
'Category'=>'Categoría',
'Street'=>'Calle',
'City'=>'Deleg./Mpio.',
'State'=>'Estado',
'Postal Code'=>'Código Postal',
'Country'=>'País',
'Description'=>'Descripción',
'Po Box'=>'Colonia',

//Mapping for price book
'Price Book Name'=>'Nombre de la Lista de precios ',
'Product Name'=>'Nombre de Producto',
'Active'=>'Activo',

//Added for 4.2 Release -- CustomView
'LBL_ALL'=>'Todo',
'LBL_VENDOR_SEARCH_FORM_TITLE'=>'Buscar Proveedor',
'LBL_PRICEBOOK_SEARCH_FORM_TITLE'=>'Buscar Listas de precios',
'LBL_VENDOR_TITLE'=>'Proveedores',
'LBL_PRICEBOOK_TITLE'=>'Listas de precios',
'LBL_PRODUCTS_TITLE'=>'Productos',
'LBL_COMPANY_NAME'=>'Nombre de la Empresa',
'LBL_CATEGORY_TITLE'=>'Categoría',
'LBL_ACTIVE_TITLE'=>'Activo',
'LBL_LIST_VENDOR_NAME'=>'Nombre del Proveedor',
'LBL_IMAGE_INFORMATION'=>'Información de la Imagen del Producto:',
'Product Image'=>'Imagen del Producto',
'LBL_ADD_PRICEBOOK_BUTTON_TITLE'=>'Agregar a las Listas de precios [Alt+B]',
'LBL_ADD_PRICEBOOK_BUTTON_KEY'=>'B',
'LBL_ADD_PRICEBOOK_BUTTON_LABEL'=>'Agregar a las Listas de precios',
'LBL_ADD_PRODUCT_PRICEBOOKS'=>'Agregar producto a las Listas de precios',
'LBL_ADD_PRODUCTS_PRICEBOOK'=>'Agregar producto a las Listas de precios',

//Added for 4.2 patch2 release
'LBL_MAXIMUM_LIMIT_ERROR'=>'El archivo excede el límite de tamaño máximo. Pruebe con otro archivo menor que 800Kbytes',
'LBL_UPLOAD_ERROR'=>'Problemas con el archivo. ¡Inténtelo de nuevo!',
'LBL_IMAGE_ERROR'=>'El archivo no es de tipo imágen(.gif/.jpg/.png)',
'LBL_INVALID_IMAGE'=>'Archivo inválido o sin datos',
'LBL_EMAIL'=>'Email',
'Product'=>'Producto',
'LBL_EDITLISTPRICE'=>'Editar Listas de precios',

//Added for existing picklist entries

'--None--'=>'-----',

'Hardware'=>'Hardware',
'Software'=>'Software',
'CRM Applications'=>'Aplicaciones CRM',

'300-Sales-Software'=>'300-Ventas-Software',
'301-Sales-Hardware'=>'301-Ventas-Hardware',
'302-Rental-Income'=>'302-Ingresos-Facturas',
'303-Interest-Income'=>'303-Ingresos-Intereses',
'304-Sales-Software-Support'=>'304-Ventas-Software-Soporte',
'305-Sales Other'=>'305-Ventas-Otros',
'306-Internet Sales'=>'306-Ventas Internet',
'307-Service-Hardware Labor'=>'307-Ventas-Instalación de Hardware',
'308-Sales-Books'=>'308-Libros-Ventas',

'Box'=>'Caja',
'Carton'=>'Cartón',
'Caton'=>'Caton',
'Dozen'=>'Docena',
'Each'=>'Unidad',
'Hours'=>'Horas',
'Impressions'=>'Impresiones',
'Lb'=>'Kg',
'M'=>'M',
'Pack'=>'Pack',
'Pages'=>'Páginas',
'Pieces'=>'Piezas',
'Quantity'=>'Cantidad',
'Reams'=>'Resma',
'Sheet'=>'Hoja',
'Spiral Binder'=>'Encuadernado Espiral',
'Sq Ft'=>'m&sup2;',

//Added for 5.0.3
'MSG_STOCK_LEVEL'=>'Stock Bajo',
'MSG_DEAR'=>'Querido',
'MSG_CURRENT_STOCK'=>'El Stock actual',
'MSG_IN_OUR_WAREHOUSE'=>'en nuestro almacén',
'MSG_PROCURE_REQUIRED_NUMBER'=>'Atención al número de unidades, el stock está por debajo del nivel de reposición.',
'MSG_SEVERITY'=>'Importancia: Alta',
'MSG_THANKS'=>'Gracias, ',

// Added after 5.0.4 GA

'LBL_PRODUCT_PRICES'=>'Precios Productos',
'Member Of'=>'Miembro de',

// Module Sequence Numbering
'Product No' => 'Núm. Producto',
// END

'Parent Product' => 'Product Paterno',

'LBL_NO_TAXES_ASSOCIATED'=>'No hay impuestos asociados a este producto',
'Products ID' => 'Id Producto',

);

?>
